@@ -29,6 +29,7 @@ interface ISecretStorageCrypto {
 }
 
 class TransparentCrypto implements ISecretStorageCrypto {
+
 	async seal(data: string): Promise<string> {
 		return data;
 	}
@@ -45,6 +46,7 @@ const enum AESConstants {
 }
 
 class NetworkError extends Error {
+
 	constructor(inner: Error) {
 		super(inner.message);
 		this.name = inner.name;
@@ -53,10 +55,12 @@ class NetworkError extends Error {
 }
 
 class ServerKeyedAESCrypto implements ISecretStorageCrypto {
-	private _serverKey: Uint8Array | undefined = new TextEncoder().encode('{{LOCAL-STORAGE}}/{{SECURE-KEY}}');
+	private serverKey: Uint8Array | undefined = new TextEncoder().encode('{{LOCAL-STORAGE}}/{{SECURE-KEY}}');
 
-	/** Gets whether the algorithm is supported; requires a secure context */
-	public static supported() {
+	/**
+	 * Gets whether the algorithm is supported; requires a secure context
+	 */
+	static supported() {
 		return !!crypto.subtle;
 	}
 
@@ -142,8 +146,8 @@ class ServerKeyedAESCrypto implements ISecretStorageCrypto {
 	}
 
 	private async getServerKeyPart(): Promise<Uint8Array> {
-		if (this._serverKey) {
-			return this._serverKey;
+		if (this.serverKey) {
+			return this.serverKey;
 		}
 
 		let attempt = 0;
@@ -155,12 +159,15 @@ class ServerKeyedAESCrypto implements ISecretStorageCrypto {
 				if (!res.ok) {
 					throw new Error(res.statusText);
 				}
+
 				const serverKey = new Uint8Array(await res.arrayBuffer());
 				if (serverKey.byteLength !== AESConstants.KEY_LENGTH / 8) {
 					throw Error(`The key retrieved by the server is not ${AESConstants.KEY_LENGTH} bit long.`);
 				}
-				this._serverKey = serverKey;
-				return this._serverKey;
+
+				this.serverKey = serverKey;
+
+				return this.serverKey;
 			} catch (e) {
 				lastError = e instanceof Error ? e : new Error(String(e));
 				attempt++;
@@ -173,34 +180,39 @@ class ServerKeyedAESCrypto implements ISecretStorageCrypto {
 		if (lastError) {
 			throw new NetworkError(lastError);
 		}
+
 		throw new Error('Unknown error');
 	}
 }
 
 export class LocalStorageSecretStorageProvider implements ISecretStorageProvider {
-	private readonly _storageKey = 'secrets.provider';
 
-	private _secretsPromise: Promise<Record<string, string>> = this.load();
+	private readonly storageKey = 'secrets.provider';
+
+	private secretsPromise: Promise<Record<string, string>>;
 
 	type: 'in-memory' | 'persisted' | 'unknown' = 'persisted';
 
 	constructor(
 		private readonly crypto: ISecretStorageCrypto,
-	) { }
+	) {
+		this.secretsPromise = this.load();
+	}
 
 	private async load(): Promise<Record<string, string>> {
 		const record = this.loadAuthSessionFromElement();
-		// Get the secrets from localStorage
-		const encrypted = localStorage.getItem(this._storageKey);
+
+		const encrypted = localStorage.getItem(this.storageKey);
 		if (encrypted) {
 			try {
 				const decrypted = JSON.parse(await this.crypto.unseal(encrypted));
+
 				return { ...record, ...decrypted };
 			} catch (err) {
 				// TODO: send telemetry
 				console.error('Failed to decrypt secrets from localStorage', err);
 				if (!(err instanceof NetworkError)) {
-					localStorage.removeItem(this._storageKey);
+					localStorage.removeItem(this.storageKey);
 				}
 			}
 		}
@@ -244,33 +256,35 @@ export class LocalStorageSecretStorageProvider implements ISecretStorageProvider
 	}
 
 	async get(key: string): Promise<string | undefined> {
-		const secrets = await this._secretsPromise;
+		const secrets = await this.secretsPromise;
+
 		return secrets[key];
 	}
+
 	async set(key: string, value: string): Promise<void> {
-		const secrets = await this._secretsPromise;
+		const secrets = await this.secretsPromise;
 		secrets[key] = value;
-		this._secretsPromise = Promise.resolve(secrets);
+		this.secretsPromise = Promise.resolve(secrets);
 		this.save();
 	}
+
 	async delete(key: string): Promise<void> {
-		const secrets = await this._secretsPromise;
+		const secrets = await this.secretsPromise;
 		delete secrets[key];
-		this._secretsPromise = Promise.resolve(secrets);
+		this.secretsPromise = Promise.resolve(secrets);
 		this.save();
 	}
 
 	private async save(): Promise<void> {
 		try {
-			const encrypted = await this.crypto.seal(JSON.stringify(await this._secretsPromise));
-			localStorage.setItem(this._storageKey, encrypted);
+			const encrypted = await this.crypto.seal(JSON.stringify(await this.secretsPromise));
+			localStorage.setItem(this.storageKey, encrypted);
 		} catch (err) {
 			console.error(err);
 		}
 	}
 }
 
-
 class LocalStorageURLCallbackProvider extends Disposable implements IURLCallbackProvider {
 
 	private static REQUEST_ID = 0;
@@ -488,6 +502,7 @@ class WorkspaceProvider implements IWorkspaceProvider {
 				return !!result;
 			}
 		}
+
 		return false;
 	}
 
