@@ -5,10 +5,12 @@
 
 import * as dom from '../../../../../base/browser/dom.js';
 import { StandardMouseEvent } from '../../../../../base/browser/mouseEvent.js';
+import { HoverPosition } from '../../../../../base/browser/ui/hover/hoverWidget.js';
+import { findLast } from '../../../../../base/common/arraysFind.js';
 import { Codicon } from '../../../../../base/common/codicons.js';
 import { Emitter } from '../../../../../base/common/event.js';
-import { Disposable, DisposableStore, IDisposable } from '../../../../../base/common/lifecycle.js';
-import { autorun } from '../../../../../base/common/observable.js';
+import { Disposable, DisposableStore, IDisposable, MutableDisposable } from '../../../../../base/common/lifecycle.js';
+import { autorun, IObservable } from '../../../../../base/common/observable.js';
 import { equalsIgnoreCase } from '../../../../../base/common/strings.js';
 import { ThemeIcon } from '../../../../../base/common/themables.js';
 import { URI } from '../../../../../base/common/uri.js';
@@ -25,29 +27,34 @@ import { IMenuService, MenuId } from '../../../../../platform/actions/common/act
 import { IContextKeyService } from '../../../../../platform/contextkey/common/contextkey.js';
 import { IContextMenuService } from '../../../../../platform/contextview/browser/contextView.js';
 import { FileKind } from '../../../../../platform/files/common/files.js';
+import { IHoverService } from '../../../../../platform/hover/browser/hover.js';
 import { IInstantiationService } from '../../../../../platform/instantiation/common/instantiation.js';
 import { ILabelService } from '../../../../../platform/label/common/label.js';
 import { IEditorService } from '../../../../services/editor/common/editorService.js';
 import { IMarkdownVulnerability } from '../../common/annotations.js';
-import { IChatEditingService } from '../../common/chatEditingService.js';
+import { IEditSessionEntryDiff } from '../../common/chatEditingService.js';
 import { IChatProgressRenderableResponseContent } from '../../common/chatModel.js';
-import { IChatMarkdownContent } from '../../common/chatService.js';
+import { IChatMarkdownContent, IChatService, IChatUndoStop } from '../../common/chatService.js';
 import { isRequestVM, isResponseVM } from '../../common/chatViewModel.js';
-import { CodeBlockModelCollection } from '../../common/codeBlockModelCollection.js';
-import { IChatCodeBlockInfo, IChatListItemRendererOptions } from '../chat.js';
+import { CodeBlockEntry, CodeBlockModelCollection } from '../../common/codeBlockModelCollection.js';
+import { IChatCodeBlockInfo } from '../chat.js';
 import { IChatRendererDelegate } from '../chatListRenderer.js';
 import { ChatMarkdownDecorationsRenderer } from '../chatMarkdownDecorationsRenderer.js';
 import { ChatEditorOptions } from '../chatOptions.js';
-import { CodeBlockPart, ICodeBlockData, localFileLanguageId, parseLocalFileData } from '../codeBlockPart.js';
+import { CodeBlockPart, ICodeBlockData, ICodeBlockRenderOptions, localFileLanguageId, parseLocalFileData } from '../codeBlockPart.js';
 import '../media/chatCodeBlockPill.css';
 import { IDisposableReference, ResourcePool } from './chatCollections.js';
 import { IChatContentPart, IChatContentPartRenderContext } from './chatContentParts.js';
 
 const $ = dom.$;
 
+export interface IChatMarkdownContentPartOptions {
+	readonly codeBlockRenderOptions?: ICodeBlockRenderOptions;
+}
+
 export class ChatMarkdownContentPart extends Disposable implements IChatContentPart {
 	private static idPool = 0;
-	public readonly id = String(++ChatMarkdownContentPart.idPool);
+	public readonly codeblocksPartId = String(++ChatMarkdownContentPart.idPool);
 	public readonly domNode: HTMLElement;
 	private readonly allRefs: IDisposableReference<CodeBlockPart | CollapsedCodeBlock>[] = [];
 
@@ -65,7 +72,7 @@ export class ChatMarkdownContentPart extends Disposable implements IChatContentP
 		renderer: MarkdownRenderer,
 		currentWidth: number,
 		private readonly codeBlockModelCollection: CodeBlockModelCollection,
-		private readonly rendererOptions: IChatListItemRendererOptions,
+		private readonly rendererOptions: IChatMarkdownContentPartOptions,
 		@IContextKeyService contextKeyService: IContextKeyService,
 		@ITextModelService private readonly textModelService: ITextModelService,
 		@IInstantiationService private readonly instantiationService: IInstantiationService,
@@ -73,6 +80,7 @@ export class ChatMarkdownContentPart extends Disposable implements IChatContentP
 		super();
 
 		const element = context.element;
+		const inUndoStop = (findLast(context.content, e => e.kind === 'undoStop', context.contentIndex) as IChatUndoStop | undefined)?.id;
 
 		// We release editors in order so that it's more likely that the same editor will be assigned if this element is re-rendered right away, like it often is during progressive rendering
 		const orderedDisposablesList: IDisposable[] = [];
@@ -81,11 +89,18 @@ export class ChatMarkdownContentPart extends Disposable implements IChatContentP
 		// and within this part to find it within the codeblocks array
 		let globalCodeBlockIndexStart = codeBlockStartIndex;
 		let thisPartCodeBlockIndexStart = 0;
+
+		// Don't set to 'false' for responses, respect defaults
+		const markedOpts = isRequestVM(element) ? {
+			gfm: true,
+			breaks: true,
+		} : undefined;
+
 		const result = this._register(renderer.render(markdown.content, {
 			fillInIncompleteTokens,
 			codeBlockRendererSync: (languageId, text, raw) => {
 				const isCodeBlockComplete = !isResponseVM(context.element) || context.element.isComplete || !raw || codeblockHasClosingBackticks(raw);
-				if ((!text || (text.startsWith('<vscode_codeblock_uri>') && !text.includes('\n'))) && !isCodeBlockComplete && rendererOptions.renderCodeBlockPills) {
+				if ((!text || (text.startsWith('<vscode_codeblock_uri') && !text.includes('\n'))) && !isCodeBlockComplete) {
 					const hideEmptyCodeblock = $('div');
 					hideEmptyCodeblock.style.display = 'none';
 					return hideEmptyCodeblock;
@@ -95,7 +110,7 @@ export class ChatMarkdownContentPart extends Disposable implements IChatContentP
 				let textModel: Promise<ITextModel>;
 				let range: Range | undefined;
 				let vulns: readonly IMarkdownVulnerability[] | undefined;
-				let codemapperUri: URI | undefined;
+				let codeblockEntry: CodeBlockEntry | undefined;
 				if (equalsIgnoreCase(languageId, localFileLanguageId)) {
 					try {
 						const parsedBody = parseLocalFileData(text);
@@ -109,14 +124,20 @@ export class ChatMarkdownContentPart extends Disposable implements IChatContentP
 					const modelEntry = this.codeBlockModelCollection.getOrCreate(sessionId, element, globalIndex);
 					const fastUpdateModelEntry = this.codeBlockModelCollection.updateSync(sessionId, element, globalIndex, { text, languageId, isComplete: isCodeBlockComplete });
 					vulns = modelEntry.vulns;
-					codemapperUri = fastUpdateModelEntry.codemapperUri;
+					codeblockEntry = fastUpdateModelEntry;
 					textModel = modelEntry.model;
 				}
 
 				const hideToolbar = isResponseVM(element) && element.errorDetails?.responseIsFiltered;
-				const codeBlockInfo: ICodeBlockData = { languageId, textModel, codeBlockIndex: globalIndex, codeBlockPartIndex: thisPartIndex, element, range, hideToolbar, parentContextKeyService: contextKeyService, vulns, codemapperUri };
+				const renderOptions = {
+					...this.rendererOptions.codeBlockRenderOptions,
+				};
+				if (hideToolbar !== undefined) {
+					renderOptions.hideToolbar = hideToolbar;
+				}
+				const codeBlockInfo: ICodeBlockData = { languageId, textModel, codeBlockIndex: globalIndex, codeBlockPartIndex: thisPartIndex, element, range, parentContextKeyService: contextKeyService, vulns, codemapperUri: codeblockEntry?.codemapperUri, renderOptions };
 
-				if (!rendererOptions.renderCodeBlockPills || element.isCompleteAddedRequest || !codemapperUri) {
+				if (element.isCompleteAddedRequest || !codeblockEntry?.codemapperUri || !codeblockEntry.isEdit) {
 					const ref = this.renderCodeBlock(codeBlockInfo, text, isCodeBlockComplete, currentWidth);
 					this.allRefs.push(ref);
 
@@ -124,12 +145,12 @@ export class ChatMarkdownContentPart extends Disposable implements IChatContentP
 					// not during a renderElement OR a progressive render (when we will be firing this event anyway at the end of the render)
 					this._register(ref.object.onDidChangeContentHeight(() => this._onDidChangeHeight.fire()));
 
-					const ownerMarkdownPartId = this.id;
-					const info: IChatCodeBlockInfo = new class {
+					const ownerMarkdownPartId = this.codeblocksPartId;
+					const info: IChatCodeBlockInfo = new class implements IChatCodeBlockInfo {
 						readonly ownerMarkdownPartId = ownerMarkdownPartId;
 						readonly codeBlockIndex = globalIndex;
-						readonly element = element;
-						readonly isStreaming = !rendererOptions.renderCodeBlockPills;
+						readonly elementId = element.id;
+						readonly isStreaming = false;
 						codemapperUri = undefined; // will be set async
 						public get uri() {
 							// here we must do a getter because the ref.object is rendered
@@ -140,16 +161,13 @@ export class ChatMarkdownContentPart extends Disposable implements IChatContentP
 						public focus() {
 							ref.object.focus();
 						}
-						public getContent(): string {
-							return ref.object.editor.getValue();
-						}
 					}();
 					this.codeblocks.push(info);
 					orderedDisposablesList.push(ref);
 					return ref.object.element;
 				} else {
 					const requestId = isRequestVM(element) ? element.id : element.requestId;
-					const ref = this.renderCodeBlockPill(element.sessionId, requestId, codeBlockInfo.codemapperUri, !isCodeBlockComplete);
+					const ref = this.renderCodeBlockPill(element.sessionId, requestId, inUndoStop, codeBlockInfo.codemapperUri, !isCodeBlockComplete);
 					if (isResponseVM(codeBlockInfo.element)) {
 						// TODO@joyceerhl: remove this code when we change the codeblockUri API to make the URI available synchronously
 						this.codeBlockModelCollection.update(codeBlockInfo.element.sessionId, codeBlockInfo.element, codeBlockInfo.codeBlockIndex, { text, languageId: codeBlockInfo.languageId, isComplete: isCodeBlockComplete }).then((e) => {
@@ -159,13 +177,13 @@ export class ChatMarkdownContentPart extends Disposable implements IChatContentP
 						});
 					}
 					this.allRefs.push(ref);
-					const ownerMarkdownPartId = this.id;
-					const info: IChatCodeBlockInfo = new class {
+					const ownerMarkdownPartId = this.codeblocksPartId;
+					const info: IChatCodeBlockInfo = new class implements IChatCodeBlockInfo {
 						readonly ownerMarkdownPartId = ownerMarkdownPartId;
 						readonly codeBlockIndex = globalIndex;
-						readonly element = element;
+						readonly elementId = element.id;
 						readonly isStreaming = !isCodeBlockComplete;
-						readonly codemapperUri = codemapperUri;
+						readonly codemapperUri = codeblockEntry?.codemapperUri;
 						public get uri() {
 							return undefined;
 						}
@@ -173,9 +191,6 @@ export class ChatMarkdownContentPart extends Disposable implements IChatContentP
 						public focus() {
 							return ref.object.element.focus();
 						}
-						public getContent(): string {
-							return ''; // Not needed for collapsed code blocks
-						}
 					}();
 					this.codeblocks.push(info);
 					orderedDisposablesList.push(ref);
@@ -183,7 +198,7 @@ export class ChatMarkdownContentPart extends Disposable implements IChatContentP
 				}
 			},
 			asyncRenderCallback: () => this._onDidChangeHeight.fire(),
-		}));
+		}, markedOpts));
 
 		const markdownDecorationsRenderer = instantiationService.createInstance(ChatMarkdownDecorationsRenderer);
 		this._register(markdownDecorationsRenderer.walkTreeAndAnnotateReferenceLinks(markdown, result.element));
@@ -192,8 +207,8 @@ export class ChatMarkdownContentPart extends Disposable implements IChatContentP
 		this.domNode = result.element;
 	}
 
-	private renderCodeBlockPill(sessionId: string, requestId: string, codemapperUri: URI | undefined, isStreaming: boolean): IDisposableReference<CollapsedCodeBlock> {
-		const codeBlock = this.instantiationService.createInstance(CollapsedCodeBlock, sessionId, requestId);
+	private renderCodeBlockPill(sessionId: string, requestId: string, inUndoStop: string | undefined, codemapperUri: URI | undefined, isStreaming: boolean): IDisposableReference<CollapsedCodeBlock> {
+		const codeBlock = this.instantiationService.createInstance(CollapsedCodeBlock, sessionId, requestId, inUndoStop);
 		if (codemapperUri) {
 			codeBlock.render(codemapperUri, isStreaming);
 		}
@@ -222,7 +237,7 @@ export class ChatMarkdownContentPart extends Disposable implements IChatContentP
 
 	hasSameContent(other: IChatProgressRenderableResponseContent): boolean {
 		return other.kind === 'markdownContent' && !!(other.content.value === this.markdown.content.value
-			|| this.rendererOptions.renderCodeBlockPills && this.codeblocks.at(-1)?.isStreaming && this.codeblocks.at(-1)?.codemapperUri !== undefined && other.content.value.lastIndexOf('```') === this.markdown.content.value.lastIndexOf('```'));
+			|| this.codeblocks.at(-1)?.isStreaming && this.codeblocks.at(-1)?.codemapperUri !== undefined && other.content.value.lastIndexOf('```') === this.markdown.content.value.lastIndexOf('```'));
 	}
 
 	layout(width: number): void {
@@ -287,16 +302,22 @@ class CollapsedCodeBlock extends Disposable {
 
 	public readonly element: HTMLElement;
 
+	private readonly hover = this._register(new MutableDisposable());
+	private tooltip: string | undefined;
+
 	private _uri: URI | undefined;
 	public get uri(): URI | undefined {
 		return this._uri;
 	}
 
+	private _currentDiff: IEditSessionEntryDiff | undefined;
+
 	private readonly _progressStore = this._store.add(new DisposableStore());
 
 	constructor(
-		sessionId: string,
-		requestId: string,
+		private readonly sessionId: string,
+		private readonly requestId: string,
+		private readonly inUndoStop: string | undefined,
 		@ILabelService private readonly labelService: ILabelService,
 		@IEditorService private readonly editorService: IEditorService,
 		@IModelService private readonly modelService: IModelService,
@@ -304,13 +325,20 @@ class CollapsedCodeBlock extends Disposable {
 		@IContextMenuService private readonly contextMenuService: IContextMenuService,
 		@IContextKeyService private readonly contextKeyService: IContextKeyService,
 		@IMenuService private readonly menuService: IMenuService,
-		@IChatEditingService private readonly chatEditingService: IChatEditingService,
+		@IHoverService private readonly hoverService: IHoverService,
+		@IChatService private readonly chatService: IChatService,
 	) {
 		super();
 		this.element = $('.chat-codeblock-pill-widget');
 		this.element.classList.add('show-file-icons');
 		this._register(dom.addDisposableListener(this.element, 'click', async () => {
-			if (this.uri) {
+			if (this._currentDiff) {
+				this.editorService.openEditor({
+					original: { resource: this._currentDiff.originalURI },
+					modified: { resource: this._currentDiff.modifiedURI },
+					options: { transient: true },
+				});
+			} else if (this.uri) {
 				this.editorService.openEditor({ resource: this.uri });
 			}
 		}));
@@ -322,7 +350,7 @@ class CollapsedCodeBlock extends Disposable {
 				contextKeyService: this.contextKeyService,
 				getAnchor: () => event,
 				getActions: () => {
-					const menu = this.menuService.getMenuActions(MenuId.ChatEditingCodeBlockContext, this.contextKeyService, { arg: { sessionId, requestId, uri: this.uri } });
+					const menu = this.menuService.getMenuActions(MenuId.ChatEditingCodeBlockContext, this.contextKeyService, { arg: { sessionId, requestId, uri: this.uri, stopId: inUndoStop } });
 					return getFlatContextMenuActions(menu);
 				},
 			});
@@ -334,9 +362,13 @@ class CollapsedCodeBlock extends Disposable {
 
 		this._uri = uri;
 
+		const session = this.chatService.getSession(this.sessionId);
 		const iconText = this.labelService.getUriBasenameLabel(uri);
-		const modifiedEntry = this.chatEditingService.currentEditingSession?.getEntry(uri);
-		const isComplete = !modifiedEntry?.isCurrentlyBeingModified.get();
+
+		let editSession = session?.editingSessionObs?.promiseResult.get()?.data;
+		let modifiedEntry = editSession?.getEntry(uri);
+		let modifiedByResponse = modifiedEntry?.isCurrentlyBeingModifiedBy.get();
+		const isComplete = !modifiedByResponse || modifiedByResponse.requestId !== this.requestId;
 
 		let iconClasses: string[] = [];
 		if (isStreaming || !isComplete) {
@@ -351,49 +383,77 @@ class CollapsedCodeBlock extends Disposable {
 		iconEl.classList.add(...iconClasses);
 
 		const children = [dom.$('span.icon-label', {}, iconText)];
+		const labelDetail = dom.$('span.label-detail', {}, '');
+		children.push(labelDetail);
 		if (isStreaming) {
-			children.push(dom.$('span.label-detail', {}, localize('chat.codeblock.generating', "Generating edits...")));
-		} else if (!isComplete) {
-			children.push(dom.$('span.label-detail', {}, ''));
+			labelDetail.textContent = localize('chat.codeblock.generating', "Generating edits...");
 		}
+
 		this.element.replaceChildren(iconEl, ...children);
-		this.element.title = this.labelService.getUriLabel(uri, { relative: false });
+		this.updateTooltip(this.labelService.getUriLabel(uri, { relative: false }));
+
+		const renderDiff = (changes: IEditSessionEntryDiff | undefined) => {
+			const labelAdded = this.element.querySelector('.label-added') ?? this.element.appendChild(dom.$('span.label-added'));
+			const labelRemoved = this.element.querySelector('.label-removed') ?? this.element.appendChild(dom.$('span.label-removed'));
+			if (changes && !changes?.identical && !changes?.quitEarly) {
+				this._currentDiff = changes;
+				labelAdded.textContent = `+${changes.added}`;
+				labelRemoved.textContent = `-${changes.removed}`;
+				const insertionsFragment = changes.added === 1 ? localize('chat.codeblock.insertions.one', "1 insertion") : localize('chat.codeblock.insertions', "{0} insertions", changes.added);
+				const deletionsFragment = changes.removed === 1 ? localize('chat.codeblock.deletions.one', "1 deletion") : localize('chat.codeblock.deletions', "{0} deletions", changes.removed);
+				const summary = localize('summary', 'Edited {0}, {1}, {2}', iconText, insertionsFragment, deletionsFragment);
+				this.element.ariaLabel = summary;
+				this.updateTooltip(summary);
+			}
+		};
+
+		let diffBetweenStops: IObservable<IEditSessionEntryDiff | undefined> | undefined;
 
 		// Show a percentage progress that is driven by the rewrite
 
 		this._progressStore.add(autorun(r => {
+			if (!editSession) {
+				editSession = session?.editingSessionObs?.promiseResult.read(r)?.data;
+				modifiedEntry = editSession?.getEntry(uri);
+			}
+
+			modifiedByResponse = modifiedEntry?.isCurrentlyBeingModifiedBy.read(r);
+			const isComplete = !modifiedByResponse || modifiedByResponse.requestId !== this.requestId;
 			const rewriteRatio = modifiedEntry?.rewriteRatio.read(r);
 
-			const labelDetail = this.element.querySelector('.label-detail');
-			const isComplete = !modifiedEntry?.isCurrentlyBeingModified.read(r);
-			if (labelDetail && !isStreaming && !isComplete) {
+			if (!isStreaming && !isComplete) {
 				const value = rewriteRatio;
-				labelDetail.textContent = value === 0 || !value ? localize('chat.codeblock.applying', "Applying edits...") : localize('chat.codeblock.applyingPercentage', "Applying edits ({0}%)...", Math.round(value * 100));
-			} else if (labelDetail && !isStreaming && isComplete) {
+				labelDetail.textContent = value === 0 || !value ? localize('chat.codeblock.generating', "Generating edits...") : localize('chat.codeblock.applyingPercentage', "Applying edits ({0}%)...", Math.round(value * 100));
+			} else if (!isStreaming && isComplete) {
 				iconEl.classList.remove(...iconClasses);
 				const fileKind = uri.path.endsWith('/') ? FileKind.FOLDER : FileKind.FILE;
 				iconEl.classList.add(...getIconClasses(this.modelService, this.languageService, uri, fileKind));
 				labelDetail.textContent = '';
 			}
 
-			if (!isStreaming && isComplete) {
-				const labelAdded = this.element.querySelector('.label-added') ?? this.element.appendChild(dom.$('span.label-added'));
-				const labelRemoved = this.element.querySelector('.label-removed') ?? this.element.appendChild(dom.$('span.label-removed'));
-				const changes = modifiedEntry?.diffInfo.read(r);
-				if (changes && !changes?.identical && !changes?.quitEarly) {
-					let removedLines = 0;
-					let addedLines = 0;
-					for (const change of changes.changes) {
-						removedLines += change.original.endLineNumberExclusive - change.original.startLineNumber;
-						addedLines += change.modified.endLineNumberExclusive - change.modified.startLineNumber;
-					}
-					labelAdded.textContent = `+${addedLines}`;
-					labelRemoved.textContent = `-${removedLines}`;
-					const insertionsFragment = addedLines === 1 ? localize('chat.codeblock.insertions.one', "1 insertion") : localize('chat.codeblock.insertions', "{0} insertions", addedLines);
-					const deletionsFragment = removedLines === 1 ? localize('chat.codeblock.deletions.one', "1 deletion") : localize('chat.codeblock.deletions', "{0} deletions", removedLines);
-					this.element.ariaLabel = this.element.title = localize('summary', 'Edited {0}, {1}, {2}', iconText, insertionsFragment, deletionsFragment);
-				}
+			if (!diffBetweenStops) {
+				diffBetweenStops = modifiedEntry && editSession
+					? editSession.getEntryDiffBetweenStops(modifiedEntry.modifiedURI, this.requestId, this.inUndoStop)
+					: undefined;
+			}
+
+			if (!isStreaming && isComplete && diffBetweenStops) {
+				renderDiff(diffBetweenStops.read(r));
 			}
 		}));
 	}
+
+	private updateTooltip(tooltip: string): void {
+		this.tooltip = tooltip;
+		if (!this.hover.value) {
+			this.hover.value = this.hoverService.setupDelayedHover(this.element, () => (
+				{
+					content: this.tooltip!,
+					appearance: { compact: true, showPointer: true },
+					position: { hoverPosition: HoverPosition.BELOW },
+					persistence: { hideOnKeyDown: true },
+				}
+			));
+		}
+	}
 }
