@@ -3,6 +3,7 @@
  *  Licensed under the MIT License. See License.txt in the project root for license information.
  *--------------------------------------------------------------------------------------------*/
 
+import { getFontSnippets } from '../../../../base/browser/fonts.js';
 import { KeyCode, KeyMod } from '../../../../base/common/keyCodes.js';
 import { Schemas } from '../../../../base/common/network.js';
 import { isIOS, isWindows } from '../../../../base/common/platform.js';
@@ -50,6 +51,7 @@ import { TerminalContextKeyStrings, TerminalContextKeys } from '../common/termin
 import { terminalStrings } from '../common/terminalStrings.js';
 import { registerSendSequenceKeybinding } from './terminalKeybindings.js';
 import { setupCheTerminalMenus } from './che/terminalMenus.js';
+import { TerminalTelemetryContribution } from './terminalTelemetry.js';
 
 // Register services
 registerSingleton(ITerminalLogService, TerminalLogService, InstantiationType.Delayed);
@@ -64,10 +66,11 @@ registerSingleton(ITerminalProfileService, TerminalProfileService, Instantiation
 // This contribution blocks startup as it's critical to enable the web embedder window.createTerminal API
 registerWorkbenchContribution2(TerminalMainContribution.ID, TerminalMainContribution, WorkbenchPhase.BlockStartup);
 registerWorkbenchContribution2(RemoteTerminalBackendContribution.ID, RemoteTerminalBackendContribution, WorkbenchPhase.AfterRestored);
+registerWorkbenchContribution2(TerminalTelemetryContribution.ID, TerminalTelemetryContribution, WorkbenchPhase.AfterRestored);
 
 // Register configurations
 registerTerminalPlatformConfiguration();
-registerTerminalConfiguration();
+registerTerminalConfiguration(getFontSnippets);
 
 // Register editor/dnd contributions
 Registry.as<IEditorFactoryRegistry>(EditorExtensions.EditorFactory).registerEditorSerializer(TerminalEditorInput.ID, TerminalInputSerializer);
